@@ -1,4 +1,4 @@
-%% Copyright (C) 2018 Colin B. Macdonald
+%% Copyright (C) 2018-2019, 2022 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -45,15 +45,17 @@
 %%   @result{} C = (sym)
 %%             10         8         6        4       2
 %%       1024⋅x   - 2304⋅x  + 1792⋅x  - 560⋅x  + 60⋅x  - 1
+%% @c doctest: +XFAIL_IF(compare_versions (OCTAVE_VERSION(), '6.0.0', '<'))
 %% value1 = polyval (sym2poly (C), 0.96105)
-%%   @result{} value1 = 0.22194
+%%   @result{} value1 = 0.2219
 %% @end group
 %% @end example
 %% Instead, we could use the present function:
 %% @example
 %% @group
+%% @c doctest: +XFAIL_IF(compare_versions (OCTAVE_VERSION(), '6.0.0', '<'))
 %% value2 = chebyshevU (10, 0.96105)
-%%   @result{} value2 = 0.22194
+%%   @result{} value2 = 0.2219
 %% @end group
 %% @end example
 %% Both results look similar but @code{value2} is more accurate---they
@@ -67,7 +69,7 @@
 %%
 %% @strong{Note} this function may be slow for large numbers of inputs.
 %% This is because it is not a native double-precision implementation
-%% but rather the numerical evaluation of the SymPy function
+%% but rather the numerical evaluation of the Python @code{mpmath} function
 %% @code{chebyshevu}.
 %%
 %% Developer note: would likely be faster if implemented directly
@@ -96,19 +98,20 @@ function y = chebyshevU (n, x)
           '    Ln = Ln*len(Lx)'
           'if len(Ln) != 1 and len(Lx) == 1:'
           '    Lx = Lx*len(Ln)'
-          'c = [complex(chebyshevu(complex(n), complex(x))) for n,x in zip(Ln, Lx)]'
+          'c = [complex(mpmath.chebyu(n, x)) for n,x in zip(Ln, Lx)]'
           'return c,' };
-  c = python_cmd (cmd, num2cell (n(:)), num2cell (x(:)));
+  c = pycall_sympy__ (cmd, num2cell (n(:)), num2cell (x(:)));
   for i = 1:numel (c)
     y(i) = c{i};
   end
 end
 
 
+%!error chebyshevU (1)
+%!error chebyshevU (1, 2, 3)
+
 %!error <sizes> chebyshevU ([1 2], [1 2 3])
 %!error <sizes> chebyshevU ([1 2], [1; 2])
-%!error <Invalid> chebyshevU (1, 2, 3)
-%!error <Invalid> chebyshevU (1)
 
 %!test
 %! y = sym(11)/10;
@@ -157,3 +160,10 @@ end
 %! A = chebyshevU (s, x);
 %! B = double (chebyshevU (t, y));
 %! assert (A, B, -2*eps);
+
+%!xtest
+%! % https://github.com/fredrik-johansson/mpmath/issues/469
+%! assert (chebyshevU (4, inf), inf)
+%! assert (chebyshevU (4, -inf), inf)
+%! assert (chebyshevU (3, inf), inf)
+%! assert (chebyshevU (3, -inf), -inf)
