@@ -1,4 +1,4 @@
-%% Copyright (C) 2015, 2016 Colin B. Macdonald
+%% Copyright (C) 2015, 2016, 2019, 2022 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -65,12 +65,12 @@ function n = degree(p, x)
     x = sym('x');
   end
 
-  n = python_cmd ('return sympy.degree(*_ins),', sym(p), sym(x));
+  n = pycall_sympy__ ('return sympy.degree(*_ins),', sym(p), sym(x));
 
 end
 
 
-%!error <Invalid> degree (sym(1), 2, 3)
+%!error degree (sym(1), 2, 3)
 
 %!test
 %! syms x
