@@ -1,4 +1,4 @@
-%% Copyright (C) 2014, 2016 Colin B. Macdonald
+%% Copyright (C) 2014, 2016, 2019 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -56,7 +56,7 @@ function n = nnz(A)
     'return n,'
   };
 
-  n = python_cmd (cmd, A);
+  n = pycall_sympy__ (cmd, A);
 
 end
 
