@@ -1,4 +1,5 @@
 %% Copyright (C) 2016 Utkarsh Gautam
+%% Copyright (C) 2019, 2022 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -45,8 +46,6 @@
 %% @seealso{@@sym/unique}
 %% @end defmethod
 
-%% Author: Utkarsh Gautam
-%% Keywords: symbolic, sort
 
 function s = sort(f)
   if (nargin ~= 1)
@@ -66,16 +65,16 @@ function s = sort(f)
       };
     if (rows(f)>1)
       f = f';
-      s = python_cmd (cmd, f);
+      s = pycall_sympy__ (cmd, f);
       s = s';
     else
-      s = python_cmd (cmd, f);
+      s = pycall_sympy__ (cmd, f);
     end
   end
 end
 
 
-%!error <Invalid> sort (sym(1), 2)
+%!error sort (sym(1), 2)
 
 %!test
 %! f = [sym(1), sym(0)];
