@@ -1,4 +1,4 @@
-%% Copyright (C) 2016 Colin B. Macdonald
+%% Copyright (C) 2016, 2019 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -37,7 +37,7 @@
 
 function h = uminus(f)
 
-  h = symfun(-f.sym, f.vars);
+  h = symfun(-formula(f), f.vars);
 
 end
 
