@@ -1,4 +1,5 @@
-%% Copyright (C) 2014-2018 Colin B. Macdonald
+%% Copyright (C) 2014-2018, 2022, 2024 Colin B. Macdonald
+%% Copyright (C) 2018-2019 Osella Giancarlo
 %%
 %% This file is part of OctSymPy.
 %%
@@ -31,7 +32,7 @@
 %% @code{@var{info}.raw}: the raw output, for debugging.
 %% @end deftypefun
 
-function [A, info] = python_ipc_sysoneline(what, cmd, mktmpfile, varargin)
+function [A, info] = python_ipc_sysoneline(what, cmd, varargin)
 
   persistent first_time
 
@@ -68,7 +69,7 @@ function [A, info] = python_ipc_sysoneline(what, cmd, mktmpfile, varargin)
   % Windows.  We have a 8000 char budget, and the header uses all
   % of it.
   mydir = fileparts (mfilename ('fullpath'));
-  mydir = strrep ([mydir filesep()], '\', '\\');
+  mydir = strrep ([mydir filesep()], '\', '\\\\');
   % execfile() only works on python 2
   headers = ['exec(open(\"' mydir 'python_header.py\").read()); '];
   %s = python_header_embed2();
@@ -111,23 +112,9 @@ function [A, info] = python_ipc_sysoneline(what, cmd, mktmpfile, varargin)
 
   bigs = [headers s1 s2 s3];
 
-  if (~mktmpfile)
-    %% paste all the commands into the system() command line
-    % python -c
-    [status,out] = system([pyexec ' -c "' bigs '"']);
-  else
-    %% Generate a temp shell script then execute it with system()
-    % This is for debugging ipc; not intended for general use
-    fname = 'tmp_python_cmd.sh';
-    fd = fopen(fname, 'w');
-    fprintf(fd, '#!/bin/sh\n\n');
-    fprintf(fd, '# temporary autogenerated code\n\n');
-    fputs(fd, [pyexec ' -c "']);
-    fputs(fd, bigs);
-    fputs(fd, '"');
-    fclose(fd);
-    [status,out] = system(['sh ' fname]);
-  end
+  %% paste all the commands into the system() command line
+  % python -c
+  [status,out] = system([pyexec ' -c "' bigs '"']);
 
   info.raw = out;
 
@@ -175,5 +162,11 @@ function s = myesc(s)
     % /" -> ///////" -> ///" -> /" -> "
     s{i} = strrep(s{i}, '"', '\\\"');
 
+    if (ispc () && (~isunix ()))
+      % escape sequence for Windows (Octave & Matlab)
+      s{i} = strrep(s{i}, '>', '^>');
+      s{i} = strrep(s{i}, '<', '^<');
+    end
+
   end
 end
