@@ -1,6 +1,7 @@
-%% Copyright (C) 2014-2019 Colin B. Macdonald
+%% Copyright (C) 2014-2020, 2022-2023 Colin B. Macdonald
 %% Copyright (C) 2017 NVS Abhilash
 %% Copyright (C) 2017 Mike Miller
+%% Copyright (C) 2022 Alex Vong
 %%
 %% This file is part of OctSymPy.
 %%
@@ -38,28 +39,6 @@
 %%   @print{} ...
 %% @end example
 %%
-%% Get the name of the @strong{Python executable}:
-%% @example
-%% @comment doctest: +SKIP
-%% sympref python
-%%   @result{} ans = python
-%% @end example
-%%
-%% Changing the Python executable might help if you've installed
-%% a local Python interpreter somewhere else on your system.
-%% The value can be changed by setting the environment variable
-%% @code{PYTHON}, which can be configured in the OS, or it can be
-%% set within Octave using:
-%% @example
-%% @comment doctest: +SKIP
-%% setenv PYTHON python3
-%% setenv PYTHON $@{HOME@}/.local/bin/python
-%% setenv PYTHON C:\Python\python.exe
-%% sympref reset
-%% @end example
-%% If the environment variable is empty or not set, the package
-%% uses a default setting (often @code{python}).
-%%
 %%
 %% @strong{Display} of syms:
 %%
@@ -107,33 +86,55 @@
 %% @end group
 %% @end example
 %%
-%% The default will typically be the @code{popen2} mechanism which
-%% uses a pipe to communicate with Python and should be fairly fast.
-%% If that doesn't work, try @code{sympref display system} which is
-%% much slower, as a new Python
-%% process is started for each operation (many commands use more
-%% than one operation).
+%% This default depends on your system.  If you have loaded the
+%% @uref{https://gitlab.com/gnu-octave/octave-pythonic, Pythonic package},
+%% the default will be the @code{native} mechanism.
+%% Otherwise, typically the @code{popen2} mechanism will be used,
+%% which uses a pipe to communicate with Python.
+%% If that doesn't work, try @code{sympref ipc system} which is
+%% much slower, as a new Python process is started for each operation.
+%%
 %% Other options for @code{sympref ipc} include:
 %% @itemize
-%% @item @code{sympref ipc popen2}: force popen2 choice (e.g.,
-%% on Matlab were it would not be the default).
-%% @item @code{sympref ipc native}: use native Python/C interface to
-%% interact directly with an embedded Python interpreter.
-%% This is highly experimental and requires functions provided by the
-%% ``pytave'' project which have not yet been merged into Octave.
+%% @item @code{sympref ipc popen2}: force popen2 choice.
+%% @item @code{sympref ipc native}: use the @code{py} interface to
+%% interact directly with an embedded Python interpreter, e.g.,
+%% provided by the Octave Pythonic package.
 %% @item @code{sympref ipc system}: construct a long string of
 %% the command and pass it directly to the python interpreter with
 %% the @code{system()} command.  This typically assembles a multiline
 %% string for the commands, except on Windows where a long one-line
 %% string is used.
 %% @item @code{sympref ipc systmpfile}: output the python commands
-%% to a @code{tmp_python_cmd.py} file and then call that [for
-%% debugging, may not be supported long-term].
+%% to a file in @code{tempdir} and then call that.
+%% For debugging, will not be supported long-term.
 %% @item @code{sympref ipc sysoneline}: put the python commands all
 %% on one line and pass to @code{python -c} using a call to @code{system()}.
-%% [for debugging, may not be supported long-term].
+%% For debugging, will not be supported long-term.
 %% @end itemize
 %%
+%% Except for @code{native}, all of these communication interfaces
+%% depend on the current @strong{Python executable}, which can be queried:
+%% @example
+%% @comment doctest: +SKIP
+%% sympref python
+%%   @result{} ans = python
+%% @end example
+%% Changing this might help if you've installed
+%% a local Python interpreter somewhere else on your system.
+%% The value can be changed by setting the environment variable
+%% @code{PYTHON}, which can be configured in the OS, or it can be
+%% set within Octave using:
+%% @example
+%% @comment doctest: +SKIP
+%% setenv PYTHON python3
+%% setenv PYTHON $@{HOME@}/.local/bin/python
+%% setenv PYTHON C:\Python\python.exe
+%% sympref reset
+%% @end example
+%% If the environment variable is empty or not set, the package
+%% uses a default setting (often @code{python}).
+%%
 %%
 %% @strong{Reset}: reset the SymPy communication mechanism.  This can be
 %% useful after an error occurs and the connection with Python
@@ -173,7 +174,7 @@
 %% @example
 %% @group
 %% sympref version
-%%   @result{} 2.8.0
+%%   @result{} 3.2.1
 %% @end group
 %% @end example
 %%
@@ -216,7 +217,7 @@ function varargout = sympref(cmd, arg)
 
     case 'version'
       assert (nargin == 1)
-      varargout{1} = '2.8.0';
+      varargout{1} = '3.2.1';
 
     case 'display'
       if (nargin == 1)
@@ -312,28 +313,26 @@ function varargout = sympref(cmd, arg)
 
     case 'reset'
       verbose = ~sympref('quiet');
-      r = python_ipc_driver('reset', []);
-
-      if (nargout == 0)
-        if (~r)
-          disp('Problem resetting');
-        end
-      else
-        varargout{1} = r;
-      end
+      python_ipc_driver('reset', []);
 
     %case 'path'
       %pkg_path = fileparts (mfilename ('fullpath'));
       % or
       %pkg_l = pkg ('list');
-      %idx = strcmp ('octsympy', cellfun (@(x) x.name, pkg_l, "UniformOutput", false));
+      %idx = strcmp ('octsympy', cellfun (@(x) x.name, pkg_l, 'UniformOutput', false));
       %if (~ any (idx))
       %  error ('the package %s is not installed', your_pkg);
       %end
       %pkg_path = pkg_l{idx}.dir
 
     case 'diagnose'
-      assert_have_python_and_sympy (sympref ('python'), true)
+      if (strcmp (lower (sympref ('ipc')), 'default') && ...
+          exist ('pyversion') && exist ('pyexec') && exist ('pyeval'))
+        % TODO: see note in ipc_native
+        assert_pythonic_and_sympy (true)
+      else
+        assert_have_python_and_sympy (sympref ('python'), true)
+      end
 
     otherwise
       error ('sympref: invalid preference or command ''%s''', lower (cmd));
@@ -375,35 +374,35 @@ end
 %% Test for correct line numbers in Python exceptions.  These first tests
 %% happen with the default ipc---usually popen2.  We don't explicitly test
 %% popen2 because test suite should be portable.
-%!error <line 1> python_cmd('raise ValueError');
-%!error <line 1> python_cmd('raise ValueError', sym('x'));
-%!error <line 1> python_cmd('raise ValueError', sym([1 2 3; 4 5 6]));
-%!error <line 1> python_cmd('raise ValueError', {1; 1; 1});
-%!error <line 1> python_cmd('raise ValueError', struct('a', 1, 'b', 'word'));
-%!error <line 2> python_cmd( {'x = 1' 'raise ValueError'} );
-%!error <line 3> python_cmd( {'x = 1' 'pass' '1/0'} );
-%!error <line 3> python_cmd( {'a=1' 'b=1' 'raise ValueError' 'c=1' 'd=1'} );
+%!error <line 1> pycall_sympy__ ('raise ValueError');
+%!error <line 1> pycall_sympy__ ('raise ValueError', sym('x'));
+%!error <line 1> pycall_sympy__ ('raise ValueError', sym([1 2 3; 4 5 6]));
+%!error <line 1> pycall_sympy__ ('raise ValueError', {1; 1; 1});
+%!error <line 1> pycall_sympy__ ('raise ValueError', struct('a', 1, 'b', 'word'));
+%!error <line 2> pycall_sympy__ ( {'x = 1' 'raise ValueError'} );
+%!error <line 3> pycall_sympy__ ( {'x = 1' 'pass' '1/0'} );
+%!error <line 3> pycall_sympy__ ( {'a=1' 'b=1' 'raise ValueError' 'c=1' 'd=1'} );
 
 %% Test for correct line error in Python exceptions.
-%!error <raise ValueError> python_cmd('raise ValueError');
-%!error <raise ValueError> python_cmd('raise ValueError', sym('x'));
-%!error <raise ValueError> python_cmd('raise ValueError', sym([1 2 3; 4 5 6]));
-%!error <raise ValueError> python_cmd('raise ValueError', {1; 1; 1});
-%!error <raise ValueError> python_cmd('raise ValueError', struct('a', 1, 'b', 'word'));
-%!error <raise ValueError> python_cmd( {'x = 1' 'raise ValueError'} );
-%!error <1/0> python_cmd( {'x = 1' 'pass' '1/0'} );
-%!error <raise ValueError> python_cmd( {'a=1' 'b=1' 'raise ValueError' 'c=1' 'd=1'} );
+%!error <raise ValueError> pycall_sympy__ ('raise ValueError');
+%!error <raise ValueError> pycall_sympy__ ('raise ValueError', sym('x'));
+%!error <raise ValueError> pycall_sympy__ ('raise ValueError', sym([1 2 3; 4 5 6]));
+%!error <raise ValueError> pycall_sympy__ ('raise ValueError', {1; 1; 1});
+%!error <raise ValueError> pycall_sympy__ ('raise ValueError', struct('a', 1, 'b', 'word'));
+%!error <raise ValueError> pycall_sympy__ ( {'x = 1' 'raise ValueError'} );
+%!error <1/0> pycall_sympy__ ( {'x = 1' 'pass' '1/0'} );
+%!error <raise ValueError> pycall_sympy__ ( {'a=1' 'b=1' 'raise ValueError' 'c=1' 'd=1'} );
 
 %!test
 %! % system should work on all system, but just runs sysoneline on windows
 %! sympref('ipc', 'system');
 %! syms x
 
-%!error <line 1> python_cmd('raise ValueError')
-%!error <line 1> python_cmd('raise ValueError', sym('x'))
-%!error <line 1> python_cmd('raise ValueError', struct('a', 1, 'b', 'word'))
+%!error <line 1> pycall_sympy__ ('raise ValueError')
+%!error <line 1> pycall_sympy__ ('raise ValueError', sym('x'))
+%!error <line 1> pycall_sympy__ ('raise ValueError', struct('a', 1, 'b', 'word'))
 
-%!error <c=1; raise ValueError> python_cmd ({'a=1' 'b=1' 'c=1; raise ValueError' 'd=1'});
+%!error <c=1; raise ValueError> pycall_sympy__ ({'a=1' 'b=1' 'c=1; raise ValueError' 'd=1'});
 
 
 %!test
@@ -411,21 +410,16 @@ end
 %! sympref('ipc', 'sysoneline');
 %! syms x
 
-%!error <line 1> python_cmd('raise ValueError')
-%!error <line 1> python_cmd('raise ValueError', struct('a', 1, 'b', 'word'))
+%!error <line 1> pycall_sympy__ ('raise ValueError')
+%!error <line 1> pycall_sympy__ ('raise ValueError', struct('a', 1, 'b', 'word'))
 
 
 %!test
 %! sympref('ipc', 'systmpfile');
 %! syms x
-%! delete('tmp_python_cmd.py')
 
-%!error <line 1> python_cmd('raise ValueError')
-%!error <line 1> python_cmd('raise ValueError', struct('a', 1, 'b', 'word'))
-
-%!test
-%! % (just to cleanup after the error tests)
-%! delete('tmp_python_cmd.py')
+%!error <line 1> pycall_sympy__ ('raise ValueError')
+%!error <line 1> pycall_sympy__ ('raise ValueError', struct('a', 1, 'b', 'word'))
 
 %!test
 %! s = warning ('off', 'OctSymPy:sympref:invalidarg');
@@ -457,12 +451,11 @@ end
 
 %!test
 %! syms x
-%! r = sympref('reset');
+%! sympref('reset');
 %! % restore original sympref settings
 %! sympref ('ipc',   sympref_orig.ipc);
 %! syms x
 %! sympref ('quiet', sympref_orig.quiet);
-%! assert(r)
 
 %!error <invalid preference or command> sympref ('nosuchsetting')
 %!error <invalid preference or command> sympref ('nosuchsetting', true)
